@@ -195,14 +195,16 @@ def test_value_error_is_raised_if_program_is_invalid():
         assert False, "Expected error"
     except ValueError as error:
         expected_error_strs = [
-            # jq 1.6
+            # jq 1.6 on Unix
             "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting $end (Unix shell quoting issues?) at <top-level>, line 1:\n!\njq: 1 compile error",
-            # jq 1.7
-            "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting end of file (Unix shell quoting issues?) at <top-level>, line 1:\n!\njq: 1 compile error",
-            # jq 1.6 -win
+            # jq 1.6 on Windows
             "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting $end (Windows cmd shell quoting issues?) at <top-level>, line 1:\n!\njq: 1 compile error",
-            # jq 1.7 -win
+            # jq 1.7 on Unix
+            "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting end of file (Unix shell quoting issues?) at <top-level>, line 1:\n!\njq: 1 compile error",
+            # jq 1.7 on Windows
             "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting end of file (Windows cmd shell quoting issues?) at <top-level>, line 1:\n!\njq: 1 compile error",
+            # jq 1.8
+            "jq: error: syntax error, unexpected INVALID_CHARACTER, expecting end of file at <top-level>, line 1, column 1:\n    !\n    ^\njq: 1 compile error",
         ]
         assert str(error) in expected_error_strs
 
@@ -217,6 +219,16 @@ def test_value_error_is_raised_if_input_cannot_be_processed_by_program():
         assert_equal(str(error), expected_error_str)
 
 
+def test_non_string_error_is_converted_to_json_text():
+    program = jq.compile("error")
+    try:
+        program.input({"x": 1}).all()
+        assert False, "Expected error"
+    except ValueError as error:
+        expected_error_str = '{"x": 1}'
+        assert_equal(str(error), expected_error_str)
+
+
 def test_errors_do_not_leak_between_transformations():
     program = jq.compile(".x")
     try:
